.. cover title comes from README.rst

.. include:: ../../README.rst

Installation
------------
.. toctree::
   :maxdepth: 2

   install/index

Configuration options
---------------------
.. toctree::
   :maxdepth: 2

   configuration/index

Administration Guide
--------------------
.. toctree::
   :maxdepth: 2

   admin/index

Contributor Guide
-----------------
.. toctree::
   :maxdepth: 2

   contributor/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

